@@ -1,5 +1,5 @@
 import warnings
-from multiprocessing.pool import Pool
+from pathos.multiprocessing import ProcessPool as Pool
 from typing import Union, Callable, List
 
 from tqdm import tqdm
@@ -67,13 +67,19 @@ class MapfwBenchmarker:
 
             while self.status["state"] == "RUNNING":
                 if self.timeout:
-                    solve_func = lambda problem: func_timeout(self.timeout / 1000, self.solver, args=(problem,))
+                    def solve_func(problem):
+                        try:
+                            sol = func_timeout(self.timeout / 1000, self.solver, args=(problem,))
+                        except:
+                            sol = None
+                        return sol
                 else:
-                    solve_func = lambda problem: self.solver(problem)
-                time_func = lambda problem: time_fun(problem,solve_func)
+                    def solve_func(problem):
+                        return self.solver(problem)
+                time_func = lambda problem: time_fun(problem, solve_func)
 
                 with Pool() as p:
-                    solutions = list(tqdm(p.imap(time_func,self.problems)))
+                    solutions = list(tqdm(p.imap(time_func, self.problems), total=len(self.problems)))
 
                 for p in range(len(self.problems)):
                     self.problems[p].add_solution(*solutions[p])
